@@ -105,6 +105,10 @@ module RSpec
       #  so you can stub constants in other contexts (e.g. helper
       #  classes).
       def self.stub(constant_name, value, options={})
+        unless String === constant_name
+          raise ArgumentError, "`stub_const` requires a String, but you provided a #{constant_name.class.name}"
+        end
+
         mutator = if recursive_const_defined?(constant_name, &raise_on_invalid_const)
                     DefinedConstantReplacer
                   else
